@@ -1420,7 +1420,9 @@ namespace Tomboy
 			note = manager.Create ();
 			if (templateNote != null) {
 				// Use the body from the template note
-				string xmlContent = templateNote.XmlContent.Replace (templateNote.Title, note.Title);
+				string xmlContent = templateNote.XmlContent.Replace (XmlEncoder.Encode (templateNote.Title),
+					XmlEncoder.Encode (note.Title));
+				xmlContent = NoteManager.SanitizeXmlContent (xmlContent);
 				note.XmlContent = xmlContent;
 			}
 
